#!/usr/bin/env python

from distutils.core import setup

setup(name='Pierwszy',
      version='1.0',
      description='Python Distribution Utilities',
      author='Jerzy Grynczewski',
      author_email='jgrynczewski@gmail.com',
     )